@@ -914,11 +914,15 @@ GtkWidget *cache_view(appdata_t *appdata, cache_t *cache) {
     notebook_append_page(notebook, 
 	     cache_tbs(appdata, cache->tb), _("TBs"));
 
-  notebook_append_page(notebook, 
-	   cache_notes(cache_context), _("Notes"));
+  /* the demo caches don't have coordinates, so avoid */
+  /* having to deal with them */
+  if(!isnan(cache->pos.lat) && !isnan(cache->pos.lon)) {
+    notebook_append_page(notebook, 
+			 cache_notes(cache_context), _("Notes"));
 
-  notebook_append_page(notebook, 
-	   goto_cache(cache_context), _("Goto"));
+    notebook_append_page(notebook, 
+			 goto_cache(cache_context), _("Goto"));
+  }
 
   g_signal_connect(notebook_object(notebook), "switch-page", 
 	   G_CALLBACK(on_notebook_page_change), cache_context);
