@@ -20,7 +20,7 @@
 #ifndef MAP_TOOL_H
 #define MAP_TOOL_H
 
-typedef enum { MAP_NONE=0, MAP_ALL, MAP_GPX, MAP_CACHE } map_state_t;
+typedef enum { MAP_NONE=0, MAP_ALL, MAP_GPX, MAP_CACHE, MAP_SEARCH } map_state_t;
 
 typedef struct {
   char *id;
@@ -32,7 +32,6 @@ typedef struct map_context_s {
   GtkWidget *widget;
   gint handler_id;
   cache_t *balloon, *press_on;
-  gboolean map_complete;
   map_state_t state;
   void *cb_id;
 
