@@ -48,33 +48,6 @@ void gtk_text_buffer_set_rich_text_format(GtkTextBuffer *buffer, const gchar *);
 
 #define TAG_STATE  GTK_STATE_PRELIGHT
 
-static GtkWidget *check_button_new_with_label(char *label) {
-#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
-  return gtk_check_button_new_with_label(label);
-#else
-  GtkWidget *cbut = 
-    hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH);
-  gtk_button_set_label(GTK_BUTTON(cbut), label);
-  return cbut;
-#endif
-}
-
-static void check_button_set_active(GtkWidget *button, gboolean active) {
-#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), active);
-#else
-  hildon_check_button_set_active(HILDON_CHECK_BUTTON(button), active);
-#endif
-}
-
-static gboolean check_button_get_active(GtkWidget *button) {
-#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
-  return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
-#else
-  return hildon_check_button_get_active(HILDON_CHECK_BUTTON(button));
-#endif
-}
-
 static notes_t *notes_load(appdata_t *appdata, cache_t *cache) {
   notes_t *notes = NULL;
   xmlDoc *doc = NULL;
@@ -198,9 +171,14 @@ static int notes_write_file(cache_context_t *context,
 		      char *text, pos_t pos, 
 		      gboolean override, gboolean found, 
 		      time_t ftime, gboolean logged) {
+
+  g_assert(context);
+  g_assert(context->cache);
+
   /* build local path */
   int path_len = strlen(context->appdata->image_path) +
     2 * strlen(context->cache->id) + 6;
+
   char *path = malloc(path_len);
   snprintf(path, path_len, "%s%s/%s.gpx",
 	   context->appdata->image_path,
@@ -273,6 +251,10 @@ static void notes_save(cache_context_t *context) {
   /* or has been changed */
 
   if(context->notes.modified) {
+#ifdef USE_STACKABLE_WINDOW
+    context->notes_have_been_changed = TRUE;
+#endif
+
     printf("something has been modified, saving notes\n");
 
     GtkTextIter start;
@@ -283,8 +265,8 @@ static void notes_save(cache_context_t *context) {
 					  &start, &end, FALSE);
     
     pos_t pos;
-    pos.lat = lat_get(context->notes.latw);
-    pos.lon = lon_get(context->notes.lonw);
+    pos.lat = lat_entry_get(context->notes.latw);
+    pos.lon = lon_entry_get(context->notes.lonw);
 
     gboolean override = 
       check_button_get_active(context->notes.overridew);
@@ -293,24 +275,15 @@ static void notes_save(cache_context_t *context) {
     gboolean logged =
       check_button_get_active(context->notes.loggedw);
 
-    /* required accuracy is 1/60000 degree */
-    if(((int)(pos.lat * 60000 + .5) != 
-	(int)(context->cache->pos.lat * 60000 + .5)) ||
-       ((int)(pos.lon * 60000 + .5) != 
-	(int)(context->cache->pos.lon * 60000 + .5)))
-      printf("position is modified %f != %f / %f != %f\n",
-	     pos.lat * 60000 + .5, context->cache->pos.lat * 60000 + .5,
-	     pos.lon * 60000 + .5, context->cache->pos.lon * 60000 + .5);
+    if(pos_differ(&pos, &context->cache->pos)) 
+      printf("position is modified\n");
     if(override || found)
       printf("flags are set\n");
     if(strlen(text))
       printf("text is present\n");
 
     /* check if the notes are empty */
-    if(((int)(pos.lat * 60000 + .5) == 
-	(int)(context->cache->pos.lat * 60000 + .5)) &&
-       ((int)(pos.lon * 60000 + .5) == 
-	(int)(context->cache->pos.lon * 60000 + .5)) &&
+    if(!pos_differ(&pos, &context->cache->pos) &&
        !override && !found && !logged && (strlen(text) == 0)) {
       printf("notes are in default state, removing them if present\n");
 
@@ -363,11 +336,11 @@ static void notes_save(cache_context_t *context) {
       /* we have to do two things here: */
       /* - update the notes.xml file on disk */
       /* - update the notes entry in the loaded gpx tree */
-      
+    
       /* update file on disk */
       notes_write_file(context, text, pos, override, found, 
 		       context->notes.ftime, logged);
-    
+
       /* search for matching caches and replace note there */
       notes_t *note = NULL;
       gpx_t *gpx = context->appdata->gpx;
@@ -458,7 +431,7 @@ static void on_destroy_textview(GtkWidget *widget, gpointer data) {
 static void ftime_update(GtkWidget *widget, cache_context_t *context, 
 			 gboolean update) {
   /* check if it has been selected */
-  if(check_button_get_active(GTK_TOGGLE_BUTTON(widget))) {
+  if(check_button_get_active(widget)) {
     printf("set active\n");
 
     if(update)
@@ -618,16 +591,17 @@ GtkWidget *cache_notes(cache_context_t *context) {
   GtkWidget *table = gtk_table_new(2, 4, FALSE);
 #if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
   gtk_table_set_col_spacing(GTK_TABLE(table), 0, 16);
-  gtk_table_set_col_spacing(GTK_TABLE(table), 2, 16);
 #endif
 
+  gtk_table_set_col_spacing(GTK_TABLE(table), 2, 16);
+
   gtk_table_attach_defaults(GTK_TABLE(table),
 		    gtk_label_new(_("New coordinate:")), 0, 1, 0, 1);  
   context->notes.overridew = check_button_new_with_label(_("Override"));
   check_button_set_active(context->notes.overridew, 
 			  cache->notes && cache->notes->override);
   gtk_table_attach_defaults(GTK_TABLE(table),
-			    context->notes.overridew, 0, 1, 1, 2);  
+			    context->notes.overridew, 2, 3, 0, 1);
 
   GtkWidget *hbox = gtk_hbox_new(FALSE, 2);
 
@@ -659,7 +633,7 @@ GtkWidget *cache_notes(cache_context_t *context) {
   if(cache->notes) pos = cache->notes->pos;
 
   gtk_table_attach_defaults(GTK_TABLE(table), 
-	    context->notes.latw = lat_entry_new(pos.lat), 2, 3, 0, 1);
+	    context->notes.latw = lat_entry_new(pos.lat), 0, 1, 1, 2);
   g_signal_connect(G_OBJECT(context->notes.latw), "focus-out-event", 
 		   G_CALLBACK(focus_out), context);
   
@@ -696,6 +670,13 @@ GtkWidget *cache_notes(cache_context_t *context) {
   hildon_text_view_set_buffer(HILDON_TEXT_VIEW(view), context->notes.buffer);
 #endif
 
+  /* if the cache has been marked found in the logs already, there's */
+  /* no need/use to be able to change all this */
+  if(cache->found) {
+    gtk_widget_set_sensitive(table, FALSE);
+    gtk_widget_set_sensitive(view, FALSE);
+  }
+
   gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(view), GTK_WRAP_WORD);
   gtk_text_view_set_editable(GTK_TEXT_VIEW(view), TRUE);
   gtk_text_view_set_left_margin(GTK_TEXT_VIEW(view), 2 );
@@ -755,8 +736,8 @@ void notes_free(notes_t *notes) {
 pos_t notes_get_pos(cache_context_t *context) {
   pos_t pos = context->cache->pos;
   if(check_button_get_active(context->notes.overridew)) {
-    pos.lat = lat_get(context->notes.latw);
-    pos.lon = lon_get(context->notes.lonw);
+    pos.lat = lat_entry_get(context->notes.latw);
+    pos.lon = lon_entry_get(context->notes.lonw);
   }
   return pos;
 }
@@ -770,58 +751,8 @@ typedef struct {
   GtkWidget *info_label;
   GtkWidget *dialog;
   appdata_t *appdata;
-  GtkWidget *path_label;
 } export_context_t;
 
-static void on_browse(GtkWidget *widget, gpointer data) {
-  GtkWidget *dialog;
-
-  export_context_t *context = (export_context_t*)data;
-
-#ifdef USE_MAEMO
-  dialog = hildon_file_chooser_dialog_new(GTK_WINDOW(context->dialog), 
-					  GTK_FILE_CHOOSER_ACTION_SAVE);
-#else
-  dialog = gtk_file_chooser_dialog_new(_("Save POI database"),
-				       GTK_WINDOW(context->dialog),
-				       GTK_FILE_CHOOSER_ACTION_SAVE,
-				       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-				       NULL);
-#endif
-
-  printf("set filename <%s>\n", context->appdata->fieldnotes_path);
-
-  if(!g_file_test(context->appdata->fieldnotes_path, G_FILE_TEST_EXISTS)) {
-    char *last_sep = strrchr(context->appdata->fieldnotes_path, '/');
-    if(last_sep) {
-      *last_sep = 0;  // seperate path from file 
-
-      /* the user just created a new document */
-      gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog), 
-					  context->appdata->fieldnotes_path);
-      gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(dialog), last_sep+1);
-
-      /* restore full filename */
-      *last_sep = '/';
-    }
-  } else 
-    gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(dialog), 
-				  context->appdata->fieldnotes_path);
-
-  if (gtk_dialog_run (GTK_DIALOG(dialog)) == GTK_FM_OK) {
-    gchar *name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
-    if(name) {
-      free(context->appdata->fieldnotes_path);
-      context->appdata->fieldnotes_path = strdup(name);
-      gtk_label_set_text(GTK_LABEL(context->path_label), 
-			 context->appdata->fieldnotes_path);
-    }
-  }
-  
-  gtk_widget_destroy (dialog);
-}
-
 typedef struct log_chain_s {
   cache_t *cache;
   struct log_chain_s *next;
@@ -911,24 +842,12 @@ void notes_log_export(appdata_t *appdata) {
   /* ------------------ path/file ------------------ */
   gtk_box_pack_start_defaults(GTK_BOX(vbox), gtk_hseparator_new());
 
-  GtkWidget *hbox = gtk_hbox_new(FALSE, 0);
-  GtkWidget *label = gtk_label_new(_("Export to:"));
-  gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE,0);
-  gtk_misc_set_alignment(GTK_MISC(label), 0.f, 0.5f);
-  GtkWidget *button = gtk_button_new_with_label(_("Browse"));
-  gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		     GTK_SIGNAL_FUNC(on_browse), (gpointer)&context);
-  gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE,0);
-  gtk_box_pack_start_defaults(GTK_BOX(vbox), hbox);
+  gtk_box_pack_start_defaults(GTK_BOX(vbox),
+     export_file(_("Save POI database"), &appdata->fieldnotes_path));
 
-  context.path_label = gtk_label_new(appdata->fieldnotes_path);
-  gtk_misc_set_alignment(GTK_MISC(context.path_label), 0.f, 0.5f);
-  gtk_label_set_ellipsize(GTK_LABEL(context.path_label), 
-			  PANGO_ELLIPSIZE_MIDDLE);
-  gtk_box_pack_start_defaults(GTK_BOX(vbox), context.path_label);
-
-  label = gtk_label_new(_("(a %s in the filename will be replaced by the "
-			  "current date and time)"));
+  GtkWidget *label = 
+    gtk_label_new(_("(a %s in the filename will be replaced by the "
+		    "current date and time)"));
   gtk_label_set_line_wrap_mode(GTK_LABEL(label), PANGO_WRAP_WORD);
   gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
   gtk_misc_set_alignment(GTK_MISC(label), 0.f, 0.5f);
